==> zither-1.1.8.tar.gz: zither-prj/apollon/block_newedit.php <==
<?php
require("./total.inc");


session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }



echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
// window.onload=WinCls();
//-->";
echo "</SCRIPT>";

print("</head>\n");
print("<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>\n");

print("<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=100%>\n");
print("<tr><td align=left><font color='ffffff'><b>ƻ -> ֥åɲáԽ</b></font></td></tr>\n");
print("</table>\n");
echo "<pre>";
print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");
print("Ǵƻ֥åޤ\n");
print("ƥ֥åñ̤Ǽ¹Ի֤ꤹ뤳ȤǽǤ\n");
echo "ܤȤ";
echo "<a target=help href='./block_help.html'>  </a>";
echo "ǧƤ";

echo "\n";
echo "<FORM METHOD=GET ACTION='block_upnew.php' target=block_upnew>";

echo "<TABLE cellspacing=0 cellpadding=3 nowrap border=1 Bordercolor='$my_bocolor' nowrap border=0 WIDTH='790' height='8%'BGCOLOR='#e6e8fa'>";



// echo "<TABLE  cellspacing=0 cellpadding=3 nowrap border=0 Bordercolor='$my_bocolor' nowrap border=0  WIDTH='90%' height='8%'BGCOLOR='#e6e8fa'>";


$BNAME = $_GET["BNAME"];
$CNAME = $_GET["CNAME"];
$MAILTO = $_GET["MAILTO"];
$MAILCC = $_GET["MAILCC"];
$MAILSEND = $_GET["MAILSEND"];
$PLUSTIME = $_GET["PLUSTIME"];
$STAT = $_GET["STAT"];
$STARTTIME = $_GET["STARTTIME"];
$STOPSETTIME = $_GET["STOPSETTIME"];
$FREE1 = $_GET["FREE1"];
$UNO = $_GET["UNO"];



$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }


if(0 != strlen($BNAME)){
   $select_data = "select * from userblock where bname='$BNAME'";
   $result = pg_query($conn, $select_data);
   if($result){
      $num = pg_num_rows($result);
      if($num == 1){
         while($s < $num){
//          echo "֥å¸ߤΤȿǤƤޤ\n";
//          echo "$select_data\n";

            $YOUNAME = rtrim(pg_fetch_Result($result, $s, youname));
            $CNAME = rtrim(pg_fetch_Result($result, $s, cname));
            $BNAME = rtrim(pg_fetch_Result($result, $s, bname));
            $MAILSEND = rtrim(pg_fetch_Result($result, $s, mailsend));
            $STAT = rtrim(pg_fetch_Result($result, $s, stat));
            $PLUSTIME = rtrim(pg_fetch_Result($result, $s, plustime));
            $STARTTIME = rtrim(pg_fetch_Result($result, $s, starttime));
            $STOPSETTIME = rtrim(pg_fetch_Result($result, $s, stopsettime));
            $MAILTO = rtrim(pg_fetch_Result($result, $s, mailto));
            $MAILCC = rtrim(pg_fetch_Result($result, $s, mailcc));
            $FREE1 = rtrim(pg_fetch_Result($result, $s, free1));
            $UNO = rtrim(pg_fetch_Result($result, $s, uno));
            $s++;
            }
         }
      }
   }


if(0 == strlen($BNAME)){
   $BNAME = "";
   }
if(0 == strlen($CNAME)){
   $CNAME = "";
   }
if(0 == strlen($MAILTO)){
   $MAILTO = "test@localhost";
   }
if(0 == strlen($MAILCC)){
   $MAILCC = "";
   }
if(0 == strlen($PLUSTIME)){
   $PLUSTIME = "60";
   }
if(1 == strlen($STAT)){
   $STAT = "NOT";
   }
if(0 == strlen($MAILSEND)){
   $MAILSEND = "OFF";
   }
if(0 == strlen($STARTTIME)){
   $STARTTIME = "0";
   }
if(0 == strlen($STOPSETTIME)){
   $STOPSETTIME = "0";
   }
if(0 == strlen($FREE1)){
   $FREE1 = "block infolmation";
   }


// ƻ륯饤ȥꥹȤκ
$cname_count = 0;
$result=pg_query($conn,"select distinct(cname) from connection;");
if(!$result){
   print("canem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($cname_count < $num){
      $xcname_data[$cname_count] = rtrim(pg_fetch_Result($result, $cname_count, cname));
      $cname_count++;
      }
   }
pg_free_result($result);






echo "<tr><td>";
echo "ƻ֥å̾\n";
echo "</td><td>";
echo "<INPUT type='text' NAME=BNAME size='48' value='$BNAME'>";
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "Υ֥åϿƻ륯饤̾\n";
echo "</td><td>";
// echo "<INPUT type='text' NAME=CNAME size='48' value='$CNAME'>";
echo "<select size=1 name=CNAME>";
echo "<option value='$CNAME'>$CNAME";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";

echo "</td></tr>";

echo "<tr><td>";
echo "ᥤTo:\n";
echo "</td><td>";
echo "<INPUT type='text' NAME=MAILTO size='48' value='$MAILTO'>";
echo "</td></tr>";

echo "<tr><td>";
echo "ᥤCc:\n";
echo "</td><td>";
echo "<INPUT type='text' NAME=MAILCC size='48' value='$MAILCC'>";
echo "</td></tr>";


echo "<tr><td>";
echo "ƻ륤󥿡Х(û)\n";
echo "</td><td>";
echo "<select size=1 name=PLUSTIME>";
echo "<option value=$PLUSTIME selected>$PLUSTIME";
echo "<option value=0>0";
echo "<option value=60>1ʬ";
echo "<option value=120>2ʬ";
echo "<option value=180>3ʬ";
echo "<option value=240>4ʬ";
echo "<option value=300>5ʬ";
echo "<option value=360>6ʬ";
echo "<option value=420>7ʬ";
echo "<option value=480>8ʬ";
echo "<option value=540>9ʬ";
echo "<option value=600>10ʬ";
echo "<option value=900>15ʬ";
echo "<option value=1200>20ʬ";
echo "<option value=1500>25ʬ";
echo "<option value=1800>30ʬ";
echo "<option value=2100>35ʬ";
echo "<option value=2400>40ʬ";
echo "<option value=2700>45ʬ";
echo "<option value=3000>50ʬ";
echo "<option value=3300>55ʬ";
echo "<option value=3600>1";
echo "</select>";
echo "</td></tr>";


echo "<tr><td>";
echo "ƻ⡼";
echo "</td><td>";
echo "<select size=1 name=STAT>";
echo "<option value=$STAT selected>$STAT";
echo "<option value=NOT>NOT";
echo "<option value=JUST>JUST";
echo "<option value=FOR>FOR";
echo "</select><br>";
echo "JUSTǻ¹ԡFORϻ( 112)˼¹<br>";
echo "JUSTϻ()˰¹Ԥޤƻ߻ꤷƤ";
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ볫ϻ(24)";
echo "</td><td>";
echo "<select size=1 name=STARTTIME>";
echo "<option value=$STARTTIME selected>$STARTTIME";
echo "<option value=0>0";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=6>6";
echo "<option value=7>7";
echo "<option value=8>8";
echo "<option value=9>9";
echo "<option value=10>10";
echo "<option value=11>11";
echo "<option value=12>12";
echo "<option value=13>13";
echo "<option value=14>14";
echo "<option value=15>15";
echo "<option value=16>16";
echo "<option value=17>17";
echo "<option value=18>18";
echo "<option value=19>19";
echo "<option value=20>20";
echo "<option value=21>21";
echo "<option value=22>22";
echo "<option value=23>23";
echo "</select>";
echo "</td></tr>";


echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ߻(24)";
echo "</td><td>";
echo "<select size=1 name=STOPSETTIME>";
echo "<option value=$STOPSETTIME selected>$STOPSETTIME";
echo "<option value=0>0";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=6>6";
echo "<option value=7>7";
echo "<option value=8>8";
echo "<option value=9>9";
echo "<option value=10>10";
echo "<option value=11>11";
echo "<option value=12>12";
echo "<option value=13>13";
echo "<option value=14>14";
echo "<option value=15>15";
echo "<option value=16>16";
echo "<option value=17>17";
echo "<option value=18>18";
echo "<option value=19>19";
echo "<option value=20>20";
echo "<option value=21>21";
echo "<option value=22>22";
echo "<option value=23>23";
echo "</select><br> JUSTξϤ餬ͭȤʤޤ </br>";
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "δƻ֥åξ";
echo "</td><td>";
echo "<INPUT type='text' NAME=FREE1 size='100' value='$FREE1'>";
echo "</td></tr>";


echo "<tr><td>";
echo "᡼ˡ";
echo "</td><td>";
echo "<select size=1 name=MAILSEND>";
echo "<option value=$MAILSEND selected>$MAILSEND";
echo "<option value=OFF>(OFF)";
echo "<option value=ON>(ON)";
echo "<option value=MID>(MID)ưַ⡼ɣ";
echo "<option value=MIX>(MIX)ưַ⡼ɣ";
echo "</select><br>";
echo "᡼߽ޤ <br>";
echo "ưַ⡼ɤȤϡϢ³顼3ޤǥ᡼ޤʸߤޤ <br>";
echo "1ξϺʴƻ뤬3Ϣ³ƹԤ줿ꥻåȤޤ<br>";
echo "2ξϺʴƻ뤬Ԥ줿ϼưǥꥻåȤޤ<br>";


echo"</table>";


echo "\n";
echo "<font color=red>";
echo "å뤳ȤǾ(Խ)ˤʤޤ<br>";
echo "</font>";
echo "<input type=submit value='ƻ֥åο'>";
echo "<INPUT type='checkbox' value='ON' NAME=EDIT>";
echo "</form>";


print("</font>");

?>

</pre>
</body>
</html>

==> zither-1.1.10.tar.gz: zither-prj/apollon/block_newedit.php <==
<?php
require("./total.inc");


session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }



echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
// window.onload=WinCls();
//-->";
echo "</SCRIPT>";

print("</head>\n");
print("<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>\n");

print("<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=100%>\n");
print("<tr><td align=left><font color='ffffff'><b>ƻ -> ֥åɲáԽ</b></font></td></tr>\n");
print("</table>\n");
echo "<pre>";
print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");
print("Ǵƻ֥åޤ\n");
print("ƥ֥åñ̤Ǽ¹Ի֤ꤹ뤳ȤǽǤ\n");
echo "ܤȤ";
echo "<a target=help href='./block_help.html'>  </a>";
echo "ǧƤ";

echo "\n";
echo "<FORM METHOD=GET ACTION='block_upnew.php' target=block_upnew>";

echo "<TABLE cellspacing=0 cellpadding=3 nowrap border=1 Bordercolor='$my_bocolor' nowrap border=0 WIDTH='790' height='8%'BGCOLOR='#e6e8fa'>";



// echo "<TABLE  cellspacing=0 cellpadding=3 nowrap border=0 Bordercolor='$my_bocolor' nowrap border=0  WIDTH='90%' height='8%'BGCOLOR='#e6e8fa'>";


$BNAME = $_GET["BNAME"];
$CNAME = $_GET["CNAME"];
$MAILTO = $_GET["MAILTO"];
$MAILCC = $_GET["MAILCC"];
$MAILSEND = $_GET["MAILSEND"];
$PLUSTIME = $_GET["PLUSTIME"];
$STAT = $_GET["STAT"];
$STARTTIME = $_GET["STARTTIME"];
$STOPSETTIME = $_GET["STOPSETTIME"];
$FREE1 = $_GET["FREE1"];
$UNO = $_GET["UNO"];


if(0 >= strlen($STAT)){
   $STAT = "NOT";
   }


$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }


if(0 != strlen($BNAME)){
   $select_data = "select * from userblock where bname='$BNAME'";
   $result = pg_query($conn, $select_data);
   if($result){
      $num = pg_num_rows($result);
      if($num == 1){
         while($s < $num){
//          echo "֥å¸ߤΤȿǤƤޤ\n";
//          echo "$select_data\n";

            $YOUNAME = rtrim(pg_fetch_Result($result, $s, youname));
            $CNAME = rtrim(pg_fetch_Result($result, $s, cname));
            $BNAME = rtrim(pg_fetch_Result($result, $s, bname));
            $MAILSEND = rtrim(pg_fetch_Result($result, $s, mailsend));
            $STAT = rtrim(pg_fetch_Result($result, $s, stat));
            $PLUSTIME = rtrim(pg_fetch_Result($result, $s, plustime));
            $STARTTIME = rtrim(pg_fetch_Result($result, $s, starttime));
            $STOPSETTIME = rtrim(pg_fetch_Result($result, $s, stopsettime));
            $MAILTO = rtrim(pg_fetch_Result($result, $s, mailto));
            $MAILCC = rtrim(pg_fetch_Result($result, $s, mailcc));
            $FREE1 = rtrim(pg_fetch_Result($result, $s, free1));
            $UNO = rtrim(pg_fetch_Result($result, $s, uno));
            $s++;
            }
         }
      }
   }


if(0 == strlen($BNAME)){
   $BNAME = "";
   }
if(0 == strlen($CNAME)){
   $CNAME = "";
   }
if(0 == strlen($MAILTO)){
   $MAILTO = "test@localhost";
   }
if(0 == strlen($MAILCC)){
   $MAILCC = "";
   }
if(0 == strlen($PLUSTIME)){
   $PLUSTIME = "60";
   }
if(1 == strlen($STAT)){
   $STAT = "NOT";
   }
if(0 == strlen($MAILSEND)){
   $MAILSEND = "OFF";
   }
if(0 == strlen($STARTTIME)){
   $STARTTIME = "00:00";
   }
if(0 == strlen($STOPSETTIME)){
   $STOPSETTIME = "00:00";
   }
if(0 == strlen($FREE1)){
   $FREE1 = "block infolmation";
   }


// ƻ륯饤ȥꥹȤκ
$cname_count = 0;
$result=pg_query($conn,"select distinct(cname) from connection;");
if(!$result){
   print("canem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($cname_count < $num){
      $xcname_data[$cname_count] = rtrim(pg_fetch_Result($result, $cname_count, cname));
      $cname_count++;
      }
   }
pg_free_result($result);






echo "<tr><td>";
echo "ƻ֥å̾\n";
echo "</td><td>";
echo "<INPUT type='text' NAME=BNAME size='48' value='$BNAME'>";
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "Υ֥åϿƻ륯饤̾\n";
echo "</td><td>";
// echo "<INPUT type='text' NAME=CNAME size='48' value='$CNAME'>";
echo "<select size=1 name=CNAME>";
echo "<option value='$CNAME'>$CNAME";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";

echo "</td></tr>";

echo "<tr><td>";
echo "ᥤTo:\n";
echo "</td><td>";
echo "<INPUT type='text' NAME=MAILTO size='48' value='$MAILTO'>";
echo "</td></tr>";

echo "<tr><td>";
echo "ᥤCc:\n";
echo "</td><td>";
echo "<INPUT type='text' NAME=MAILCC size='48' value='$MAILCC'>";
echo "</td></tr>";


echo "<tr><td>";
echo "ƻ륤󥿡Х(û)\n";
echo "</td><td>";
echo "<select size=1 name=PLUSTIME>";
echo "<option value=$PLUSTIME selected>$PLUSTIME";
echo "<option value=0>0";
echo "<option value=60>1ʬ";
echo "<option value=120>2ʬ";
echo "<option value=180>3ʬ";
echo "<option value=240>4ʬ";
echo "<option value=300>5ʬ";
echo "<option value=360>6ʬ";
echo "<option value=420>7ʬ";
echo "<option value=480>8ʬ";
echo "<option value=540>9ʬ";
echo "<option value=600>10ʬ";
echo "<option value=900>15ʬ";
echo "<option value=1200>20ʬ";
echo "<option value=1500>25ʬ";
echo "<option value=1800>30ʬ";
echo "<option value=2100>35ʬ";
echo "<option value=2400>40ʬ";
echo "<option value=2700>45ʬ";
echo "<option value=3000>50ʬ";
echo "<option value=3300>55ʬ";
echo "<option value=3600>1";
echo "</select>";
echo "</td></tr>";


echo "<tr><td>";
echo "ƻ⡼";
echo "</td><td>";
echo "<select size=1 name=STAT>";
echo "<option value=$STAT selected>$STAT";
echo "<option value=NOT>NOT";
echo "<option value=JUST>JUST";
echo "<option value=FOR>FOR";
echo "</select><br>";
echo "JUSTǻ¹ԡFORϻ( 112)˼¹<br>";
echo "JUSTϻ()˰¹Ԥޤƻ߻ꤷƤ";
echo "</td></tr>";



echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ볫ϻ(24)";
echo "</td><td>";
echo "(24:60)";
echo "<INPUT type='text' NAME=STARTTIME size='5' value='$STARTTIME' maxlength=5>";
echo "</td></tr>";


echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ߻(24)";
echo "</td><td>";
echo "(24:60)";
echo "<INPUT type='text' NAME=STOPSETTIME size='5' value='$STOPSETTIME' maxlength=5>";
echo "<br> JUSTξϤ餬ͭȤʤޤ </br>";
echo "</td></tr>";


echo "<tr bgcolor='#D9DBED'><td>";
echo "δƻ֥åξ";
echo "</td><td>";
echo "<INPUT type='text' NAME=FREE1 size='100' value='$FREE1'>";
echo "</td></tr>";


echo "<tr><td>";
echo "᡼ˡ";
echo "</td><td>";
echo "<select size=1 name=MAILSEND>";
echo "<option value=$MAILSEND selected>$MAILSEND";
echo "<option value=OFF>(OFF)";
echo "<option value=ON>(ON)";
echo "<option value=MID>(MID)ưַ⡼ɣ";
echo "<option value=MIX>(MIX)ưַ⡼ɣ";
echo "</select><br>";
echo "᡼߽ޤ <br>";
echo "ưַ⡼ɤȤϡϢ³顼3ޤǥ᡼ޤʸߤޤ <br>";
echo "1ξϺʴƻ뤬3Ϣ³ƹԤ줿ꥻåȤޤ<br>";
echo "2ξϺʴƻ뤬Ԥ줿ϼưǥꥻåȤޤ<br>";


echo"</table>";


echo "\n";
echo "<font color=red>";
echo "å뤳ȤǾ(Խ)ˤʤޤ<br>";
echo "</font>";
echo "<input type=submit value='ƻ֥åο'>";
echo "<INPUT type='checkbox' value='ON' NAME=EDIT>";
echo "</form>";


print("</font>");

?>

</pre>
</body>
</html>
